@@ -42,7 +42,9 @@ def print_groups(df: pd.DataFrame, column: str) -> None:
     for current_group, sub_df in df.groupby(column):
         print(f'Group: {current_group}')
         print()
-        print(sub_df)
+        # Skip group column
+        mask = ~(sub_df.columns.isin([column]))
+        print(sub_df.loc[:, mask])
         print()
         print('---' * 25)
 
@@ -59,6 +61,23 @@ def display_all() -> None:
     pd.set_option('display.max_rows', None)
 
 
+def no_wrapping():
+    """
+    Return a context manager to display all rows and columns.
+
+    Examples:
+    ```python
+    with no_wrapping():
+        print(df)
+    ```
+
+    Returns:
+        Context Manager
+    """
+    return pd.option_context('display.max_rows', None,
+                             'display.max_columns', None)
+
+
 def explore_df(df: pd.DataFrame) -> pd.DataFrame:
     """
     Perform a quick peek of a dataframe.
