@@ -88,23 +88,44 @@ def filter_column(df: pd.DataFrame,
              value=options)
 
 
-def download_df(df: pd.DataFrame) -> None:
+def download(file_path) -> None:
     """
-    Generate a download link for a dataframe.
+    Download a file at given path.
+
+    Args:
+        file_path: File path
+
+    Returns:
+        None
+    """
+    from IPython.display import Javascript
+    script = f'''
+            var host = window.location.host;
+            var downloadLink = window.location.protocol + "//" + host + "/files/{file_path}"
+            window.open(downloadLink)
+            '''
+    return Javascript(script)
+
+
+def download_df(df: pd.DataFrame,
+                csv_path=None) -> None:
+    """
+    Download a dataframe as a CSV with a random filename.
 
     The filename is set to a random UUID.
 
     Args:
         df: Pandas DataFrame
+        csv_path: CSV filename.
 
     Returns:
         None
     """
-    from IPython.display import FileLink, display
-    from uuid import uuid4
-    random_csv_path = f'{uuid4()}.csv'
-    df.to_csv(random_csv_path, index=False)
-    display(FileLink(random_csv_path))
+    if not csv_path:
+        from uuid import uuid4
+        csv_path = f'{uuid4()}.csv'
+    df.to_csv(csv_path, index=False)
+    return download(file_path=csv_path)
 
 
 def search_dataframe(df: pd.DataFrame) -> None:
